from enum import Enum


class SpanAttributes:
    TRACELOOP_SPAN_KIND = "traceloop.span.kind"
    TRACELOOP_WORKFLOW_NAME = "traceloop.workflow.name"
    TRACELOOP_ENTITY_NAME = "traceloop.entity.name"
    TRACELOOP_CORRELATION_ID = "traceloop.correlation_id"


class TraceloopSpanKindValues(Enum):
    WORKFLOW = "workflow"
    TASK = "task"
    AGENT = "agent"
    TOOL = "tool"
    UNKNOWN = "unknown"



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sdk', 'sdk.decorators', 'sdk.semconv', 'sdk.tracing', 'sdk.utils']

package_data = \
{'': ['*']}

install_requires = \
['opentelemetry-api>=1.19.0,<2.0.0',
 'opentelemetry-exporter-otlp-proto-http>=1.19.0,<2.0.0',
 'opentelemetry-instrumentation-openai>=0.0.3,<0.0.4',
 'opentelemetry-instrumentation-pinecone>=0.0.2,<0.0.3',
 'opentelemetry-instrumentation-pymysql>=0.40b0,<0.41',
 'opentelemetry-instrumentation-requests>=0.40b0,<0.41',
 'opentelemetry-instrumentation-urllib3>=0.40b0,<0.41',
 'opentelemetry-sdk>=1.19.0,<2.0.0']

setup_kwargs = {
    'name': 'traceloop-sdk',
    'version': '0.0.33',
    'description': 'Traceloop Software Development Kit (SDK) for Python',
    'long_description': '# traceloop-sdk\n\nProject description here.\n',
    'author': 'Gal Kleinman',
    'author_email': 'gal@traceloop.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8.1,<3.12',
}


setup(**setup_kwargs)



from typing import Optional
from traceloop.sdk.tracing.tracing import TracerWrapper, set_correlation_id


class Traceloop:
    __tracer_wrapper: TracerWrapper

    @staticmethod
    def init(app_name: Optional[str] = None) -> None:
        Traceloop.__tracer_wrapper = TracerWrapper()

    @staticmethod
    def set_correlation_id(correlation_id: str) -> None:
        set_correlation_id(correlation_id)
